@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.1-1
+# Application Name - Health Check V0.5.1-2
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -93,159 +93,22 @@ class Ui_MainWindow(object):
         self.tabWidget.setGeometry(QtCore.QRect(0, 0, 800, 420))
         # Set the font size. I've gone for big... very big - so they are finger friendly.
         font = QtGui.QFont()
-        font.setPointSize(30)
+        font.setPointSize(28)
         self.tabWidget.setFont(font)
         self.tabWidget.setObjectName("tabWidget")
         self.tab = QtGui.QWidget()
         self.tab.setObjectName("tab")
 
-        #Reset the Fontsize - decided to go with Arial 14 for all objects on tab 1
+        #Reset the Fontsize - decided to go with Arial 18 for all objects on tab 1
         font = QtGui.QFont()
         font.setPointSize(18)
 
-        # Set up the Battery label
-        self.lbl_Battery = QtGui.QLabel(self.tab)
-        self.lbl_Battery.setGeometry(QtCore.QRect(10, 0, 171, 20))
-        self.lbl_Battery.setFont(font)
-        self.lbl_Battery.setObjectName("lbl_Battery")
-        self.lbl_Battery.setText("Battery")
-
-        # Set up the Accelerator label
-        self.lbl_Accel = QtGui.QLabel(self.tab)
-        self.lbl_Accel.setGeometry(QtCore.QRect(10, 30, 171, 20))
-        self.lbl_Accel.setFont(font)
-        self.lbl_Accel.setObjectName("lbl_Accel")
-        self.lbl_Accel.setText("Accelerometer")
-
-        # This label will be used to show the Maemo Firmware version currently installed
-        self.lbl_Maemo_Version = QtGui.QLabel(self.tab)
-        self.lbl_Maemo_Version.setGeometry(QtCore.QRect(10, 60, 171, 21))
-        self.lbl_Maemo_Version.setFont(font)
-        self.lbl_Maemo_Version.setObjectName("lbl_Maemo_Version")
-        self.lbl_Maemo_Version.setText("Firmware Ver")
-
-        # This label is for the Rootfs Free space (Label only)
-        self.lbl_rootfs = QtGui.QLabel(self.tab)
-        self.lbl_rootfs.setGeometry(QtCore.QRect(10, 90, 171, 21))
-        self.lbl_rootfs.setFont(font)
-        self.lbl_rootfs.setObjectName("lbl_rootfs")
-        self.lbl_rootfs.setText("Rootfs Free")
-
-        # This label is for the Rootfs Free space (Label only)
-        self.lbl_mydocs = QtGui.QLabel(self.tab)
-        self.lbl_mydocs.setGeometry(QtCore.QRect(10, 120, 171, 21))
-        self.lbl_mydocs.setFont(font)
-        self.lbl_mydocs.setObjectName("lbl_mydocs")
-        self.lbl_mydocs.setText("MyDocs Free")
-
-        
-
-        # This label is for the CPU Info Label only)
-        self.lbl_Processor = QtGui.QLabel(self.tab)
-        self.lbl_Processor.setGeometry(QtCore.QRect(10, 150, 197, 21))
-        self.lbl_Processor.setFont(font)
-        self.lbl_Processor.setObjectName("lbl_Processor")
-        self.lbl_Processor.setText("CPU Info")
-
-        # This label is for the N900 Board info(Label only)
-        self.lbl_BoardInfol = QtGui.QLabel(self.tab)
-        self.lbl_BoardInfol.setGeometry(QtCore.QRect(10, 180, 171, 21))
-        self.lbl_BoardInfol.setFont(font)
-        self.lbl_BoardInfol.setObjectName("lbl_BoardInfol")
-        self.lbl_BoardInfol.setText("N900 Board")
-
-        # This label is for the system locale (Label only)
-        self.lbl_SysLocale = QtGui.QLabel(self.tab)
-        self.lbl_SysLocale.setGeometry(QtCore.QRect(10, 210, 171, 21))
-        self.lbl_SysLocale.setFont(font)
-        self.lbl_SysLocale.setObjectName("lbl_SysLocale")
-        self.lbl_SysLocale.setText("System Locale")
-
-        
-        
-
-
-
-        #self.lst_Listwidget1.setGeometry(QtCore.QRect(10, 210, 171, 200))
-        
-        
-        
-
-        # Start showing the Information fields - these fields i have labelled with Info(mostly!), but only because it makes sense to me!
-
-        #Set the font again
-        font = QtGui.QFont()
-        font.setPointSize(14)
-
-        #Battery Percentage bar - is acting a bit strange and being thin at the moment.
-        self.lbl_Battery_Bar = QtGui.QProgressBar(self.tab)
-        self.lbl_Battery_Bar.setGeometry(QtCore.QRect(200,-20,590,60))
-        self.lbl_Battery_Bar.setFont(font)
-        self.lbl_Battery_Bar.setProperty("value", 50)
-        self.lbl_Battery_Bar.setObjectName("lbl_Battery_Bar")
-
-        font = QtGui.QFont()
-        font.setPointSize(18)
-        #Accelorator information
-        self.lbl_Accel_Info = QtGui.QLabel(self.tab)
-        self.lbl_Accel_Info.setGeometry(QtCore.QRect(200, 30, 590, 21))
-        self.lbl_Accel_Info.setFont(font)
-        self.lbl_Accel_Info.setObjectName("lbl_Accel_Info")
-
-        # Label to show the maemo firmware version Information
-        self.lbl_Maemo_Ver_Info = QtGui.QLabel(self.tab)
-        self.lbl_Maemo_Ver_Info.setGeometry(QtCore.QRect(200, 60, 590, 21))
-        self.lbl_Maemo_Ver_Info.setFont(font)
-        self.lbl_Maemo_Ver_Info.setObjectName("lbl_Maemo_Ver_Info")
-
-        # Rootfs Info - label to show the rootfs free space (data)
-        self.lbl_rootfd_info = QtGui.QLabel(self.tab)
-        self.lbl_rootfd_info.setGeometry(QtCore.QRect(200, 90, 400, 21))
-        self.lbl_rootfd_info.setFont(font)
-        self.lbl_rootfd_info.setObjectName("lbl_rootfd_info")
-
-        # Rootfs Info - label to show the rootfs free space (data)
-        self.lbl_mydocsd_info = QtGui.QLabel(self.tab)
-        self.lbl_mydocsd_info.setGeometry(QtCore.QRect(200, 120, 400, 21))
-        self.lbl_mydocsd_info.setFont(font)
-        self.lbl_mydocsd_info.setObjectName("lbl_mydocsd_info")
-
-        # This label is for the CPU Information(Label only)
-        self.lbl_ProcessorInfo = QtGui.QLabel(self.tab)
-        self.lbl_ProcessorInfo.setGeometry(QtCore.QRect(200, 150, 400, 21))
-        self.lbl_ProcessorInfo.setFont(font)
-        self.lbl_ProcessorInfo.setObjectName("lbl_ProcessorInfo")
-        self.lbl_ProcessorInfo.setText("CPU Info")
-
-        # This label is for the N900 Motherboard/mainboard info(Label only)
-        self.lbl_BoardInfo = QtGui.QLabel(self.tab)
-        self.lbl_BoardInfo.setGeometry(QtCore.QRect(200, 180, 400, 21))
-        self.lbl_BoardInfo.setFont(font)
-        self.lbl_BoardInfo.setObjectName("lbl_BoardInfo")
-        self.lbl_BoardInfo.setText("Board Info")
-        
-        # This label is for the system locale info (Label only)
-        self.lbl_SysLocaleInfo = QtGui.QLabel(self.tab)
-        self.lbl_SysLocaleInfo.setGeometry(QtCore.QRect(200, 210, 400, 21))
-        self.lbl_SysLocaleInfo.setFont(font)
-        self.lbl_SysLocaleInfo.setObjectName("lbl_SysLocaleInfo")
-        self.lbl_SysLocaleInfo.setText("Sys Locale Info")
-
-                
-       
-
-        #self.listWidget = QtGui.QListWidget(self.tab)
-        #self.listWidget.setGeometry(QtCore.QRect(10, 210, 600, 200))
-        #for i in range(10):
-            #item = QtGui.QListWidgetItem("Item %i" % i)
-            #self.listWidget.addItem(item)
-        #self.listWidget.setObjectName("lbl_listWidget")
-        #self.listWidget.setFont(font)
-        #self.listWidget.setAlternatingRowColors(True)
-        #self.listWidget.setResizeMode(QtGui.QListView.Adjust)
-        #self.listWidget.addItem("Testing listbox")
-        #self.listWidget.show()
-        
+        self.listWidget = QtGui.QListWidget(self.tab)
+        self.listWidget.setGeometry(QtCore.QRect(10, 0, 791, 301))
+        self.listWidget.setObjectName("listWidget")
+        self.listWidget.setFont(font)
+        self.listWidget.setAlternatingRowColors(True)
+        self.listWidget.setResizeMode(QtGui.QListView.Adjust)
         
         # Setup and draw the button
         self.pushButton_hw = QtGui.QPushButton(self.tab)
@@ -258,81 +121,17 @@ class Ui_MainWindow(object):
         # Draw the Tab Contents
         self.tabWidget.addTab(self.tab, "")
 
-        
+
         # Start on tab 2!
         self.tab_2 = QtGui.QWidget()
         self.tab_2.setObjectName("tab_2")
 
-        # Set up the GPS Info label
-        self.lbl_GpsPos = QtGui.QLabel(self.tab_2)
-        self.lbl_GpsPos.setGeometry(QtCore.QRect(10, 0, 190, 21))
-        self.lbl_GpsPos.setFont(font)
-        self.lbl_GpsPos.setObjectName("lbl_GpsPos")
-        self.lbl_GpsPos.setText("GPS Position")
-        
-        
-        # GPS Info Field
-        self.lbl_Gps_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_Gps_Info.setGeometry(QtCore.QRect(220, 0, 420, 21))
-        self.lbl_Gps_Info.setObjectName("lbl_Gps_Info")
-        self.lbl_Gps_Info.setFont(font)
-
-
-        # This label is for the phone signal (Label only)
-        self.lbl_Psignal = QtGui.QLabel(self.tab_2)
-        self.lbl_Psignal.setGeometry(QtCore.QRect(10, 60, 190, 21))
-        self.lbl_Psignal.setFont(font)
-        self.lbl_Psignal.setObjectName("lbl_Psignal")
-        self.lbl_Psignal.setText("Phone Signal")
-
-        # This label is for the phone RNC (Label only)
-        self.lbl_PRNC = QtGui.QLabel(self.tab_2)
-        self.lbl_PRNC.setGeometry(QtCore.QRect(10, 90, 190, 21))
-        self.lbl_PRNC.setFont(font)
-        self.lbl_PRNC.setObjectName("lbl_PRNC")
-        self.lbl_PRNC.setText("Network Status")
-        
-        # This label is for the Phone Services (Label only)
-        self.lbl_PhoneServices = QtGui.QLabel(self.tab_2)
-        self.lbl_PhoneServices.setGeometry(QtCore.QRect(10, 120, 190, 21))
-        self.lbl_PhoneServices.setFont(font)
-        self.lbl_PhoneServices.setObjectName("lbl_PhoneServices")
-        self.lbl_PhoneServices.setText("Phone Services")
-
-        # This label is for the Cell ID(Label only)
-        self.lbl_Cell_ID = QtGui.QLabel(self.tab_2)
-        self.lbl_Cell_ID.setGeometry(QtCore.QRect(10, 150, 190, 21))
-        self.lbl_Cell_ID.setFont(font)
-        self.lbl_Cell_ID.setObjectName("lbl_Cell_ID")
-        self.lbl_Cell_ID.setText("Phone Cell_ID")
-        
-        # This label is for the Phone Signal info (Label only)
-        self.lbl_pSignal_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_pSignal_Info.setGeometry(QtCore.QRect(220, 60, 331, 21))
-        self.lbl_pSignal_Info.setFont(font)
-        self.lbl_pSignal_Info.setObjectName("lbl_pSignal_Info")
-        #self.lbl_pSignal_Info.setText("Phone Signal")
-
-        # This label was Phone RNC info now net status (Label only)
-        self.lbl_pRNC_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_pRNC_Info.setGeometry(QtCore.QRect(220, 90, 331, 21))
-        self.lbl_pRNC_Info.setFont(font)
-        self.lbl_pRNC_Info.setObjectName("lbl_pRNC_Info")
-        #self.lbl_pRNC_Info.setText("Network Status")
-
-        # This label is for the Phone services info (Label only)
-        self.lbl_pServices_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_pServices_Info.setGeometry(QtCore.QRect(220, 120, 331, 21))
-        self.lbl_pServices_Info.setFont(font)
-        self.lbl_pServices_Info.setObjectName("lbl_pServices_Info")
-        #self.lbl_pServices_Info.setText("Phone Services")
-
-        # This label is for the Cell ID info (Label only)
-        self.lbl_CellID_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_CellID_Info.setGeometry(QtCore.QRect(220, 150, 331, 21))
-        self.lbl_CellID_Info.setFont(font)
-        self.lbl_CellID_Info.setObjectName("lbl_CellID_Info")
-        #self.lbl_CellID_Info.setText("Cell ID")
+        self.listWidget2 = QtGui.QListWidget(self.tab_2)
+        self.listWidget2.setGeometry(QtCore.QRect(10, 0, 791, 301))
+        self.listWidget2.setObjectName("listWidget2")
+        self.listWidget2.setFont(font)
+        self.listWidget2.setAlternatingRowColors(True)
+        self.listWidget2.setResizeMode(QtGui.QListView.Adjust)
 
         # Setup and draw the button
         self.pushButton_com = QtGui.QPushButton(self.tab_2)
@@ -372,7 +171,7 @@ class Ui_MainWindow(object):
         self.pushButton_cam = QtGui.QPushButton(self.tab_3)
         self.pushButton_cam.setGeometry(QtCore.QRect(450, 250, 340, 51))
         self.pushButton_cam.setObjectName("pushButton_cam")
-        self.pushButton_cam.setText("Front Camera")
+        self.pushButton_cam.setText("Front camera")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
 
@@ -411,7 +210,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.1-1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.1-2 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -467,8 +266,10 @@ class Ui_MainWindow(object):
 
     
          # Set the GPS tabel text       
-        self.lbl_Gps_Info.setText(var_g_GPS)
         #self.lbl_Alt_Info.setText(var_g_ALT)
+        self.listWidget2.addItem("GPS Position \t\t" + var_g_GPS.strip())
+        
+        
         
 
     def reboot_sys(self):
@@ -518,56 +319,51 @@ class Ui_MainWindow(object):
         g.lstrip()
         g.rstrip()
 
-
+        
         if g.strip() == "3.2010.02-8":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1.1")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1.1")
         elif g.strip() == "3.2010.02-8.002":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1.1")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1.1")
         elif g.strip() == "3.2010.02-8.001":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1.1")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1.1")
         elif g.strip() == "2.2009.51-1":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1")
         elif g.strip() == "2009.51-1.203.2":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1 UK Generic Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
         elif g.strip() == "2009.51-1.203.1":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1 UK Generic Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1 UK Generic Version")
         elif g.strip() == "2009.51-1.205.1":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1 UK Vodafone Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1 UK Vodafone Version")
         elif g.strip() == "2009.51-1.205.2":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1 UK Vodafone Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.1 UK Vodafone Version")
         elif g.strip() == "1.2009.44-1":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.01")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1.01")
         elif g.strip() == "1.2009.42-11":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 - Initial public release ")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 - Initial public release ")
         elif g.strip() == "1.2009.42-11.002":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 USA Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 USA Version")
         elif g.strip() == "1.2009.42-11.003":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 Mid-East/N-Africa Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 Mid-East/N-Africa Version")
         elif g.strip() == "1.2009.42-11.203":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.203.0":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.203.1":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.203.2":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Generic Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Generic Version")
         elif g.strip() == "1.2009.42-11.205":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Vodafone Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
         elif g.strip() == "1.2009.42-11.205.0":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Vodafone Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
         elif g.strip() == "1.2009.42-11.205.1":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Vodafone Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
         elif g.strip() == "1.2009.42-11.205.2":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1 UK Vodafone Version")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - PR 1 UK Vodafone Version")
         elif g.strip() == "1.2009.41-1":
-            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Early Release Vanilla Variant")
+            self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - Early Release Vanilla Variant")
         else:
-           self.lbl_Maemo_Ver_Info.setText(g + " - Varient unknown -")
-           print "Firmware variants"
-           print g
-           print str(g)
-           print g.strip()
-           print g.find("3.2010.02-8")
+           self.listWidget.addItem("Maemo Version \t\t" + g.strip() + " - Varient unknown")
 
 
 # Funtion - update CPU Information
@@ -575,15 +371,18 @@ class Ui_MainWindow(object):
         # This one reads fremantle version number (Firmware)
         ga = os.popen('cat /proc/cpuinfo | grep Processor').read()
         ga = ga.strip()[11:]
-        self.lbl_ProcessorInfo.setText(ga.strip())
+        
+        self.listWidget.addItem("Processor Information \t" + ga.strip())
         
         gb = os.popen('cat /proc/cpuinfo | grep Hardware').read()
         gb = gb.strip()[11:]
-        self.lbl_BoardInfo.setText(gb.strip())
+        
+        self.listWidget.addItem("N900 Board \t\t\t" + gb.strip())
 
         gc = os.popen('locale | grep LANG').read()
         gc = gc.strip()[5:]
-        self.lbl_SysLocaleInfo.setText(gc.strip())
+        
+        self.listWidget.addItem("System locale \t\t" + gc.strip())
 
 # Funtion - update battery information
     def updateBatt(self):
@@ -598,8 +397,9 @@ class Ui_MainWindow(object):
         
         barxval = str.strip(C_b)
         
-        self.lbl_Battery_Bar.setRange(0,100)
-        self.lbl_Battery_Bar.setProperty("value", barxval)
+        #self.lbl_Battery_Bar.setRange(0,100)
+        #self.lbl_Battery_Bar.setProperty("value", barxval)
+        self.listWidget.addItem("Battery  \t\t\t" + barxval + "%")
 
 # Funtion - update Accelerator information
     def updateAccel(self):
@@ -616,9 +416,8 @@ class Ui_MainWindow(object):
         b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
         coords = str(coords)
         jaccel = str(coords) + str(b)
-        print jaccel
-        self.lbl_Accel_Info.setText(jaccel)
-
+        
+        self.listWidget.addItem("Accelerometer \t\t" + jaccel)
         
         #Bluetooth
         #print "performing inquiry..."
@@ -636,7 +435,8 @@ class Ui_MainWindow(object):
         # Remove some of the faffy bits. I've left the total free and percentage used at the moment, is a little confusing
         gx = str(gr)[-14:]
         gx = gx[:-7]
-        self.lbl_rootfd_info.setText(gx.strip())
+        
+        self.listWidget.addItem("Rootfs \t\t\t" + gx.strip() + " free")
 
     def updatemydocs(self):
         # Call the x-terminal command to read the rootfs free space
@@ -646,15 +446,15 @@ class Ui_MainWindow(object):
         
         gf = gf[:-24]
         
-        self.lbl_mydocsd_info.setText(gf.strip())
+        
+        self.listWidget.addItem("MyDocs \t\t\t" + gf.strip() + " free")
         
 # Funtion - update tab.... Originally to update tab1, but using it to collate the functions
 # It has the commented out message boxes, will work on this later
     def updateTab1(self):
-        
+        self.listWidget.clear()
         self.pushButton_hw.setEnabled(False)
-        self.pushButton_hw.setText(".")
-        
+        self.pushButton_hw.setText(".")  
         Thread(target=self.updaterootfs()).start()
         self.pushButton_hw.setText("..")
         Thread(target=self.updateAccel()).start()
@@ -665,15 +465,14 @@ class Ui_MainWindow(object):
         self.pushButton_hw.setText(".....")
         Thread(target=self.updateMaemoV()).start()
         self.pushButton_hw.setText("......")
-        
         self.pushButton_hw.setText(".......")
         Thread(target=self.updateBatt()).start()
         self.pushButton_hw.setText("........")
-        
         self.pushButton_hw.setText("Update")
         self.pushButton_hw.setEnabled(True)
 
     def updateTab2(self):
+        self.listWidget2.clear()
         self.pushButton_com.setEnabled(False)
         self.pushButton_com.setText("...")
         Thread(target=self.updateGPS()).start()
@@ -698,7 +497,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-1", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-2", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
@@ -739,7 +538,9 @@ class Ui_MainWindow(object):
 
 	fraction = 1.0 / 100 * signalstrength[0]
 	text = " - %d dBm" % signalstrength[1]
-        self.lbl_pSignal_Info.setText(text)
+
+        self.listWidget2.addItem("Phone Signal \t\t" + text.strip())
+        #self.lbl_pSignal_Info.setText(text)
 
 
 	#print "reg 1 %i" % regstatus[4]
@@ -748,14 +549,20 @@ class Ui_MainWindow(object):
 	cell_id = regstatus[2] & 65535
 	cell_rnc = regstatus[2] >> 16
 		
-	#if (cell_rnc): self.lbl_pRNC_Info.setText(cell_rnc)
-	#else: print " "
-	self.lbl_pRNC_Info.setText(status)
-	self.lbl_CellID_Info.setText(str(cell_id))
+	self.listWidget2.addItem("Cell RNC \t\t" + str(cell_rnc).strip())
+        ##
+        self.listWidget2.addItem("Cell Status \t\t" + status)
+	#self.lbl_pRNC_Info.setText(status)
+        self.listWidget2.addItem("Cell ID \t\t" + str(cell_id).strip())
+	#self.lbl_CellID_Info.setText(str(cell_id))
+
 	#print status
 	#print network_type
 	#print "regstatus %i" % regstatus[7]
-	self.lbl_pServices_Info.setText(services)
+
+        ##
+        self.listWidget2.addItem("Cell Services \t\t" + services)
+	#self.lbl_pServices_Info.setText(services)
 
 	##dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei
         #bus = dbus.SystemBus()
